%%
%% This is file `t2asrbenc.def',
%% copied from t2aenc.def
%% 
\NeedsTeXFormat{LaTeX2e}[1998/12/01]
\ProvidesFile{t2aenc.def}
  [2005/09/27 v1.0i Cyrillic encoding definition file]
\DeclareFontEncoding{T2ASRB}{}{}
\DeclareFontSubstitution{\LastDeclaredEncoding}{cmr}{m}{n}
\DeclareTextAccent{\`}{\LastDeclaredEncoding}{0}
\DeclareTextAccent{\'}{\LastDeclaredEncoding}{1}
\DeclareTextAccent{\^}{\LastDeclaredEncoding}{2}
\DeclareTextAccent{\~}{\LastDeclaredEncoding}{3}
\DeclareTextAccent{\"}{\LastDeclaredEncoding}{4}
\DeclareTextAccent{\H}{\LastDeclaredEncoding}{5}
\DeclareTextAccent{\r}{\LastDeclaredEncoding}{6}
\DeclareTextAccent{\v}{\LastDeclaredEncoding}{7}
\DeclareTextAccent{\u}{\LastDeclaredEncoding}{8}
\DeclareTextAccent{\=}{\LastDeclaredEncoding}{9}
\DeclareTextAccent{\.}{\LastDeclaredEncoding}{10}
\DeclareTextAccent{\f}{\LastDeclaredEncoding}{18}
\DeclareTextAccent{\C}{\LastDeclaredEncoding}{19}
\DeclareTextAccent{\U}{\LastDeclaredEncoding}{20}
\DeclareTextCommand{\b}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-3ex}%
     \vbox to.2ex{\hbox{\char9}\vss}\hidewidth}\egroup}
\DeclareTextCommand{\c}{\LastDeclaredEncoding}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\char11\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\d}{\LastDeclaredEncoding}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\ltx@sh@ft{-1ex}.\hidewidth}\egroup}
\DeclareTextCommand{\k}{\LastDeclaredEncoding}[1]
   {\oalign{\null#1\crcr\hidewidth\char12}}
\DeclareTextCommand{\textperthousand}{\LastDeclaredEncoding}
   {\%\char 24 }
\DeclareTextCommand{\textpertenthousand}{\LastDeclaredEncoding}
   {\%\char 24\char 24 }
\DeclareTextSymbol{\textendash}{\LastDeclaredEncoding}{21}
\DeclareTextSymbol{\cyrdash}{\LastDeclaredEncoding}{22}
\DeclareTextSymbol{\textemdash}{\LastDeclaredEncoding}{22}
\DeclareTextSymbol{\textcompwordmark}{\LastDeclaredEncoding}{23}
\DeclareTextSymbol{\textvisiblespace}{\LastDeclaredEncoding}{32}
\DeclareTextSymbol{\textdollar}{\LastDeclaredEncoding}{36}
\DeclareTextSymbol{\textless}{\LastDeclaredEncoding}{60}
\DeclareTextSymbol{\textgreater}{\LastDeclaredEncoding}{62}
\DeclareTextSymbol{\textbackslash}{\LastDeclaredEncoding}{92}
\DeclareTextSymbol{\textasciicircum}{\LastDeclaredEncoding}{94}
\DeclareTextSymbol{\textunderscore}{\LastDeclaredEncoding}{95}
\DeclareTextSymbol{\textbraceleft}{\LastDeclaredEncoding}{123}
\DeclareTextSymbol{\textbar}{\LastDeclaredEncoding}{124}
\DeclareTextSymbol{\textbraceright}{\LastDeclaredEncoding}{125}
\DeclareTextSymbol{\textasciitilde}{\LastDeclaredEncoding}{126}
\DeclareTextSymbol{\textnumero}{\LastDeclaredEncoding}{157}
\DeclareTextSymbol{\textcurrency}{\LastDeclaredEncoding}{158}
\DeclareTextSymbol{\textsection}{\LastDeclaredEncoding}{159}
\DeclareTextSymbol{\textquotedbl}{\LastDeclaredEncoding}{34}
\DeclareTextSymbol{\textquoteleft}{\LastDeclaredEncoding}{96}
\DeclareTextSymbol{\textquoteright}{\LastDeclaredEncoding}{39}
\DeclareTextSymbol{\textquotedblleft}{\LastDeclaredEncoding}{16}
\DeclareTextSymbol{\textquotedblright}{\LastDeclaredEncoding}{17}
\DeclareTextSymbol{\quotedblbase}{\LastDeclaredEncoding}{189}
\DeclareTextSymbol{\CYRpalochka}{\LastDeclaredEncoding}{13}
\DeclareTextSymbol{\cyrlangle}{\LastDeclaredEncoding}{14}
\DeclareTextSymbol{\cyrrangle}{\LastDeclaredEncoding}{15}
\DeclareTextSymbol{\guillemotleft}{\LastDeclaredEncoding}{190}
\DeclareTextSymbol{\guillemotright}{\LastDeclaredEncoding}{191}
\DeclareTextSymbol{\i}{\LastDeclaredEncoding}{25}
\DeclareTextSymbol{\j}{\LastDeclaredEncoding}{26}
\DeclareTextComposite{\.}{\LastDeclaredEncoding}{i}{`\i}
\DeclareTextSymbol{\CYRA}{\LastDeclaredEncoding}{192}
\DeclareTextSymbol{\cyra}{\LastDeclaredEncoding}{224}
\DeclareTextSymbol{\CYRB}{\LastDeclaredEncoding}{193}
\DeclareTextSymbol{\cyrb}{\LastDeclaredEncoding}{225}
\DeclareTextSymbol{\CYRV}{\LastDeclaredEncoding}{194}
\DeclareTextSymbol{\cyrv}{\LastDeclaredEncoding}{226}
\DeclareTextSymbol{\CYRG}{\LastDeclaredEncoding}{195}
\DeclareTextSymbol{\cyrg}{\LastDeclaredEncoding}{227}
\DeclareTextSymbol{\CYRD}{\LastDeclaredEncoding}{196}
\DeclareTextSymbol{\cyrd}{\LastDeclaredEncoding}{228}
\DeclareTextSymbol{\CYRE}{\LastDeclaredEncoding}{197}
\DeclareTextSymbol{\cyre}{\LastDeclaredEncoding}{229}
\DeclareTextSymbol{\CYRZH}{\LastDeclaredEncoding}{198}
\DeclareTextSymbol{\cyrzh}{\LastDeclaredEncoding}{230}
\DeclareTextSymbol{\CYRZ}{\LastDeclaredEncoding}{199}
\DeclareTextSymbol{\cyrz}{\LastDeclaredEncoding}{231}
\DeclareTextSymbol{\CYRI}{\LastDeclaredEncoding}{200}
\DeclareTextSymbol{\cyri}{\LastDeclaredEncoding}{232}
\DeclareTextSymbol{\CYRISHRT}{\LastDeclaredEncoding}{201}
\DeclareTextSymbol{\cyrishrt}{\LastDeclaredEncoding}{233}
\DeclareTextSymbol{\CYRK}{\LastDeclaredEncoding}{202}
\DeclareTextSymbol{\cyrk}{\LastDeclaredEncoding}{234}
\DeclareTextSymbol{\CYRL}{\LastDeclaredEncoding}{203}
\DeclareTextSymbol{\cyrl}{\LastDeclaredEncoding}{235}
\DeclareTextSymbol{\CYRM}{\LastDeclaredEncoding}{204}
\DeclareTextSymbol{\cyrm}{\LastDeclaredEncoding}{236}
\DeclareTextSymbol{\CYRN}{\LastDeclaredEncoding}{205}
\DeclareTextSymbol{\cyrn}{\LastDeclaredEncoding}{237}
\DeclareTextSymbol{\CYRO}{\LastDeclaredEncoding}{206}
\DeclareTextSymbol{\cyro}{\LastDeclaredEncoding}{238}
\DeclareTextSymbol{\CYRP}{\LastDeclaredEncoding}{207}
\DeclareTextSymbol{\cyrp}{\LastDeclaredEncoding}{239}
\DeclareTextSymbol{\CYRR}{\LastDeclaredEncoding}{208}
\DeclareTextSymbol{\cyrr}{\LastDeclaredEncoding}{240}
\DeclareTextSymbol{\CYRS}{\LastDeclaredEncoding}{209}
\DeclareTextSymbol{\cyrs}{\LastDeclaredEncoding}{241}
\DeclareTextSymbol{\CYRT}{\LastDeclaredEncoding}{210}
\DeclareTextSymbol{\cyrt}{\LastDeclaredEncoding}{242}
\DeclareTextSymbol{\CYRU}{\LastDeclaredEncoding}{211}
\DeclareTextSymbol{\cyru}{\LastDeclaredEncoding}{243}
\DeclareTextSymbol{\CYRF}{\LastDeclaredEncoding}{212}
\DeclareTextSymbol{\cyrf}{\LastDeclaredEncoding}{244}
\DeclareTextSymbol{\CYRH}{\LastDeclaredEncoding}{213}
\DeclareTextSymbol{\cyrh}{\LastDeclaredEncoding}{245}
\DeclareTextSymbol{\CYRC}{\LastDeclaredEncoding}{214}
\DeclareTextSymbol{\cyrc}{\LastDeclaredEncoding}{246}
\DeclareTextSymbol{\CYRCH}{\LastDeclaredEncoding}{215}
\DeclareTextSymbol{\cyrch}{\LastDeclaredEncoding}{247}
\DeclareTextSymbol{\CYRSH}{\LastDeclaredEncoding}{216}
\DeclareTextSymbol{\cyrsh}{\LastDeclaredEncoding}{248}
\DeclareTextSymbol{\CYRSHCH}{\LastDeclaredEncoding}{217}
\DeclareTextSymbol{\cyrshch}{\LastDeclaredEncoding}{249}
\DeclareTextSymbol{\CYRHRDSN}{\LastDeclaredEncoding}{218}
\DeclareTextSymbol{\cyrhrdsn}{\LastDeclaredEncoding}{250}
\DeclareTextSymbol{\CYRERY}{\LastDeclaredEncoding}{219}
\DeclareTextSymbol{\cyrery}{\LastDeclaredEncoding}{251}
\DeclareTextSymbol{\CYRSFTSN}{\LastDeclaredEncoding}{220}
\DeclareTextSymbol{\cyrsftsn}{\LastDeclaredEncoding}{252}
\DeclareTextSymbol{\CYREREV}{\LastDeclaredEncoding}{221}
\DeclareTextSymbol{\cyrerev}{\LastDeclaredEncoding}{253}
\DeclareTextSymbol{\CYRYU}{\LastDeclaredEncoding}{222}
\DeclareTextSymbol{\cyryu}{\LastDeclaredEncoding}{254}
\DeclareTextSymbol{\CYRYA}{\LastDeclaredEncoding}{223}
\DeclareTextSymbol{\cyrya}{\LastDeclaredEncoding}{255}
\DeclareTextSymbol{\CYRGUP}{T2ASRB}{128}
\DeclareTextSymbol{\cyrgup}{T2ASRB}{160}
\DeclareTextSymbol{\CYRGHCRS}{T2ASRB}{129}
\DeclareTextSymbol{\cyrghcrs}{T2ASRB}{161}
\DeclareTextSymbol{\CYRDJE}{T2ASRB}{130}
\DeclareTextSymbol{\cyrdje}{T2ASRB}{162}
\DeclareTextSymbol{\CYRTSHE}{T2ASRB}{131}
\DeclareTextSymbol{\cyrtshe}{T2ASRB}{163}
\DeclareTextSymbol{\CYRSHHA}{T2ASRB}{132}
\DeclareTextSymbol{\cyrshha}{T2ASRB}{164}
\DeclareTextSymbol{\CYRZHDSC}{T2ASRB}{133}
\DeclareTextSymbol{\cyrzhdsc}{T2ASRB}{165}
\DeclareTextSymbol{\CYRZDSC}{T2ASRB}{134}
\DeclareTextSymbol{\cyrzdsc}{T2ASRB}{166}
\DeclareTextSymbol{\CYRLJE}{T2ASRB}{135}
\DeclareTextSymbol{\cyrlje}{T2ASRB}{167}
\DeclareTextSymbol{\CYRYI}{T2ASRB}{136}
\DeclareTextSymbol{\cyryi}{T2ASRB}{168}
\DeclareTextSymbol{\CYRKDSC}{T2ASRB}{137}
\DeclareTextSymbol{\cyrkdsc}{T2ASRB}{169}
\DeclareTextSymbol{\CYRKBEAK}{T2ASRB}{138}
\DeclareTextSymbol{\cyrkbeak}{T2ASRB}{170}
\DeclareTextSymbol{\CYRKVCRS}{T2ASRB}{139}
\DeclareTextSymbol{\cyrkvcrs}{T2ASRB}{171}
\DeclareTextSymbol{\CYRAE}{T2ASRB}{140}
\DeclareTextSymbol{\cyrae}{T2ASRB}{172}
\DeclareTextSymbol{\CYRNDSC}{T2ASRB}{141}
\DeclareTextSymbol{\cyrndsc}{T2ASRB}{173}
\DeclareTextSymbol{\CYRNG}{T2ASRB}{142}
\DeclareTextSymbol{\cyrng}{T2ASRB}{174}
\DeclareTextSymbol{\CYRDZE}{T2ASRB}{143}
\DeclareTextSymbol{\cyrdze}{T2ASRB}{175}
\DeclareTextSymbol{\CYROTLD}{T2ASRB}{144}
\DeclareTextSymbol{\cyrotld}{T2ASRB}{176}
\DeclareTextSymbol{\CYRSDSC}{T2ASRB}{145}
\DeclareTextSymbol{\cyrsdsc}{T2ASRB}{177}
\DeclareTextSymbol{\CYRUSHRT}{T2ASRB}{146}
\DeclareTextSymbol{\cyrushrt}{T2ASRB}{178}
\DeclareTextSymbol{\CYRY}{T2ASRB}{147}
\DeclareTextSymbol{\cyry}{T2ASRB}{179}
\DeclareTextSymbol{\CYRYHCRS}{T2ASRB}{148}
\DeclareTextSymbol{\cyryhcrs}{T2ASRB}{180}
\DeclareTextSymbol{\CYRHDSC}{T2ASRB}{149}
\DeclareTextSymbol{\cyrhdsc}{T2ASRB}{181}
\DeclareTextSymbol{\CYRDZHE}{T2ASRB}{150}
\DeclareTextSymbol{\cyrdzhe}{T2ASRB}{182}
\DeclareTextSymbol{\CYRCHVCRS}{T2ASRB}{151}
\DeclareTextSymbol{\cyrchvcrs}{T2ASRB}{183}
\DeclareTextSymbol{\CYRCHRDSC}{T2ASRB}{152}
\DeclareTextSymbol{\cyrchrdsc}{T2ASRB}{184}
\DeclareTextSymbol{\CYRIE}{T2ASRB}{153}
\DeclareTextSymbol{\cyrie}{T2ASRB}{185}
\DeclareTextSymbol{\CYRSCHWA}{T2ASRB}{154}
\DeclareTextSymbol{\cyrschwa}{T2ASRB}{186}
\DeclareTextSymbol{\CYRNJE}{T2ASRB}{155}
\DeclareTextSymbol{\cyrnje}{T2ASRB}{187}
\DeclareTextSymbol{\CYRYO}{\LastDeclaredEncoding}{156}
\DeclareTextSymbol{\cyryo}{\LastDeclaredEncoding}{188}
\DeclareTextSymbol{\CYRII}{\LastDeclaredEncoding}{73}
\DeclareTextSymbol{\cyrii}{\LastDeclaredEncoding}{105}
\DeclareTextSymbol{\CYRJE}{\LastDeclaredEncoding}{74}
\DeclareTextSymbol{\cyrje}{\LastDeclaredEncoding}{106}
\DeclareTextSymbol{\CYRQ}{\LastDeclaredEncoding}{81}
\DeclareTextSymbol{\cyrq}{\LastDeclaredEncoding}{113}
\DeclareTextSymbol{\CYRW}{\LastDeclaredEncoding}{87}
\DeclareTextSymbol{\cyrw}{\LastDeclaredEncoding}{119}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\CYRE}{156}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\cyre}{188}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\CYRI}{201}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\cyri}{233}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\CYRII}{136}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\cyrii}{168}
\DeclareTextComposite{\c}{\LastDeclaredEncoding}{\CYRZ}{134}
\DeclareTextComposite{\c}{\LastDeclaredEncoding}{\cyrz}{166}
\DeclareTextComposite{\k}{\LastDeclaredEncoding}{\CYRS}{145}
\DeclareTextComposite{\k}{\LastDeclaredEncoding}{\cyrs}{177}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\CYRU}{146}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\cyru}{178}
\endinput
%%
%% End of file `t2asrbenc.def'.
